# -------------------------------------------------------------------------------
# Generated by PixieDust code generator
# 
# Licensed under the Apache License, Version 2.0 (the 'License');
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
# http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an 'AS IS' BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# Inherited from maven-artifact https://github.com/hamnis/maven-artifact
# -------------------------------------------------------------------------------

from .display import WordCloudDisplayHandler
from pixiedust.display.display import *

@PixiedustDisplay()
class WordCloudDisplayHandlerMeta(DisplayHandlerMeta):
    @addId
    def getMenuInfo(self,entity, dataHandler):
        # if we have DataFrame, include the menu option
        if entity.__class__.__name__ == "DataFrame":
            return [
                {
                    "categoryId": "Chart",
                    "title": "Simple Word Cloud",
                    "icon": "fa-cloud",
                    "id": "mySimpleWordCloud"
                }
            ]
        else:
            return []
    
    """
    Factory method that creates the displayHandler class capable of visualizing the data
    """
    def newDisplayHandler(self,options,entity):
        return WordCloudDisplayHandler(options,entity)